Improve this doc

# `ngCookies`

# ngCookies

The `ngCookies` module provides a convenient wrapper for reading and writing browser cookies.

See `$cookies` and `$cookieStore` for usage.

## Installation

First include `angular-cookies.js` in your HTML:

        <script src="angular.js">
        <script src="angular-cookies.js">

You can download this file from the following places:

- Google CDN
  e.g. `//ajax.googleapis.com/ajax/libs/angularjs/X.Y.Z/angular-cookies.js`
- Bower
  e.g.

      bower install angular-cookies@X.Y.Z

- code.angularjs.org
  e.g.

      "//code.angularjs.org/X.Y.Z/angular-cookies.js"

where X.Y.Z is the AngularJS version you are running.

Then load the module in your application by adding it as a dependent module:

      angular.module('app', ['ngCookies']);

With that you're ready to get started!

## Module Components

### Service

Name | Description
--- | ---
$cookies | Provides read/write access to browser's cookies.
$cookieStore | Provides a key-value (string-object) storage, that is backed by session cookies. Objects put or retrieved from this storage are automatically serialized or deserialized by angular's toJson/fromJson.